@@ -1,4 +1,4 @@
-# $Id: Split.pm,v 0.08 2003/12/29 16:20:53 st.schubiger Exp $
+# $Id: Split.pm,v 0.09 2003/12/29 18:18:21 st.schubiger Exp $
 
 package Dir::Split;
 
@@ -19,7 +19,7 @@ our ($scl_source_dir_ref,
      $suffix_l,
      $suffix_sep);
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 =head1 NAME
 
@@ -184,7 +184,7 @@ sub split {
     }
     $self->_eval_suffix_sum_up (\$suffix);
 
-    for (; @files; $suffix++) { print 'hello';
+    for (; @files; $suffix++) {
         # mk subdir
         my $path = File::Spec->catfile($$scl_target_dir_ref,
           "$sub_dir_ident$suffix_sep$suffix");
